declare const _default: (taskName: string) => PropertyDecorator;
/**
 * This decorator allows you to alias a property to the result of a task. You can also provide a default value to use before the task has completed.
 *
 * ```js
 * import Component from '@ember/component';
 * import { task } from 'ember-concurrency-decorators';
 * import { lastValue } from 'ember-concurrency-decorators';
 *
 * export default class ExampleComponent extends Component {
 *   @task
 *   someTask = function*() {
 *     // ...
 *   };
 *
 *   @lastValue('someTask')
 *   someTaskValue;
 *
 *   @lastValue('someTask')
 *   someTaskValueWithDefault = 'A default value';
 * }
 * ```
 *
 * @function
 * @param {string} taskName the name of the task to read a value from
 */
export default _default;
